menu
mfrc522 package
documentation
simple_mfrc522.dart
SimpleMfrc522 class
SimpleMfrc522 class
dark_mode
light_mode
SimpleMfrc522
class
Constructors
SimpleMfrc522
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
key
→
List
<
int
>
final
mfrc522
→
Mfrc522
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
trailerBlock
→
int
final
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read
(
)
→
Future
<
Map
<
String
,
dynamic
>
>
readId
(
)
→
Future
<
int
?
>
toString
(
)
→
String
A string representation of this object.
inherited
write
(
String
text
)
→
Future
<
Map
<
String
,
dynamic
>
>
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
mfrc522 package
documentation
simple_mfrc522
SimpleMfrc522 class
simple_mfrc522 library